@@ -4,8 +4,6 @@ from functools import partial
 from itertools import chain
 from typing import Any, Callable
 
-FixedPointFactory = Callable[[float], "FixedPoint"]
-
 
 def _assert_range(value: float, total_bits: int, frac_bits: int) -> None:
     max_value = 2 ** (total_bits - frac_bits - 1)
@@ -167,7 +165,7 @@ class FixedPoint:
         return FixedPoint(float_value, total_bits=total_bits, frac_bits=frac_bits)
 
     @staticmethod
-    def get_factory(total_bits: int, frac_bits: int) -> FixedPointFactory:
+    def get_factory(total_bits: int, frac_bits: int) -> Callable[[float], "FixedPoint"]:
         return partial(FixedPoint, total_bits=total_bits, frac_bits=frac_bits)
 
     @property
@@ -264,6 +262,9 @@ def infer_total_and_frac_bits(*values: Sequence[FixedPoint]) -> tuple[int, int]:
     return total_bits, frac_bits
 
 
+FixedPointFactory = Callable[[float], FixedPoint]
+
+
 def fixed_point_params_from_factory(factory: FixedPointFactory) -> tuple[int, int]:
     return factory(1).total_bits, factory(1).frac_bits
 
