@@ -10,14 +10,19 @@ from elasticai.creator.vhdl.number_representations import (
 
 class FixedPointQuantFunction(torch.autograd.Function):
     @staticmethod
-    def forward(
-        ctx: Any, x: torch.Tensor, fixed_point_factory: FixedPointFactory
-    ) -> torch.Tensor:
+    def forward(ctx: Any, *args: Any, **kwargs: Any) -> tuple[torch.Tensor, ...]:
+        if len(args) != 2:
+            raise TypeError(
+                "apply() takes exactly two arguments "
+                "(x: torch.Tensor, fixed_point_factory: Callable[[float], FixedPoint])"
+            )
+        x: torch.Tensor = args[0]
+        fixed_point_factory: FixedPointFactory = args[1]
+
         total_bits, frac_bits = fixed_point_params_from_factory(fixed_point_factory)
         largest_fp_int = 2 ** (total_bits - 1) - 1
-        return (
-            (x * (1 << frac_bits)).int().float().clamp(-largest_fp_int, largest_fp_int)
-        )
+        fp_value = (x * (1 << frac_bits)).int().float()
+        return fp_value.clamp(-largest_fp_int, largest_fp_int)
 
     @staticmethod
     def backward(ctx: Any, *grad_outputs: Any) -> Any:
@@ -26,9 +31,15 @@ class FixedPointQuantFunction(torch.autograd.Function):
 
 class FixedPointDequantFunction(torch.autograd.Function):
     @staticmethod
-    def forward(
-        ctx: Any, x: torch.Tensor, fixed_point_factory: FixedPointFactory
-    ) -> torch.Tensor:
+    def forward(ctx: Any, *args: Any, **kwargs: Any) -> tuple[torch.Tensor, ...]:
+        if len(args) != 2:
+            raise TypeError(
+                "apply() takes exactly two arguments "
+                "(x: torch.Tensor, fixed_point_factory: Callable[[float], FixedPoint])"
+            )
+        x: torch.Tensor = args[0]
+        fixed_point_factory: FixedPointFactory = args[1]
+
         total_bits, frac_bits = fixed_point_params_from_factory(fixed_point_factory)
         min_value = 2 ** (total_bits - frac_bits - 1) * (-1)
         max_value = (2 ** (total_bits - 1) - 1) / (1 << frac_bits)
