@@ -3,7 +3,7 @@ from typing import Any, Callable, Iterator
 
 from elasticai.creator.vhdl.vhdl_component import VHDLModule
 
-BuildFunction = Callable[[Any], VHDLModule]
+BuildFunction = Callable[[Any, str], VHDLModule]
 
 
 class BuildFunctionMapping(Mapping[str, BuildFunction]):
